@@ -26,25 +26,25 @@
 
 # get the list of dataflows of this provider
 getFlows <- function(provider, pattern='') {		
-  jlist <- J("it.bankitalia.reri.sia.sdmx.client.SdmxClientHandler")$getFlows(provider, pattern)
+  jlist <- J("it.bancaditalia.oss.sdmx.client.SdmxClientHandler")$getFlows(provider, pattern)
   res = convertHashTable(jlist)
 	return(res)
 }
 
 # get the key family of the given dataflow (after retrieving the key family)
 getDSDIdentifier <- function(provider, dataflow) {		
-  res <- J("it.bankitalia.reri.sia.sdmx.client.SdmxClientHandler")$getDSDIdentifier(provider, dataflow)
+  res <- J("it.bancaditalia.oss.sdmx.client.SdmxClientHandler")$getDSDIdentifier(provider, dataflow)
 	return(.jstrVal(res))
 }
 
 # add a new sdmx provider
-addProvider <- function(name, endpoint, needsCredentials=F) {  	
-  J("it.bankitalia.reri.sia.sdmx.client.SdmxClientHandler")$addProvider(name, endpoint, needsCredentials)
+addProvider <- function(name, endpoint, needsCredentials=F, needsURLEncoding=F, supportsCompression=T, description='') {  	
+  J("it.bancaditalia.oss.sdmx.client.SdmxClientHandler")$addProvider(name, endpoint, needsCredentials, needsURLEncoding, supportsCompression, description)
 }
 
 # get dimensions of the given dataflow (after retrieving the key family)
 getDimensions <- function(provider, dataflow) {           
-  res <- J("it.bankitalia.reri.sia.sdmx.client.SdmxClientHandler")$getDimensions(provider, dataflow)
+  res <- J("it.bancaditalia.oss.sdmx.client.SdmxClientHandler")$getDimensions(provider, dataflow)
   jlist <- .jcall(res,"[Ljava/lang/Object;","toArray");
   res = convertDimList(jlist)
   return(res)
@@ -57,7 +57,7 @@ getTimeSeries <- function(provider, id, start='', end='') {
 
 # get the time series matching the parameters
 getSDMX <- function(provider, id, start='', end='') {
-  res <- J("it.bankitalia.reri.sia.sdmx.client.SdmxClientHandler")$getTimeSeries(provider, id, start, end)
+  res <- J("it.bancaditalia.oss.sdmx.client.SdmxClientHandler")$getTimeSeries(provider, id, start, end)
   #convert to an R list
   res = convertTSList(res)
   return(res) 
@@ -65,19 +65,33 @@ getSDMX <- function(provider, id, start='', end='') {
 
 # get the list of available data providers
 getProviders <- function() {		
-  jlist <- J("it.bankitalia.reri.sia.sdmx.client.SdmxClientHandler")$getProviders()
+  jlist <- J("it.bancaditalia.oss.sdmx.client.SdmxClientHandler")$getProviders()
 	res = convertStringList(jlist)
 	return(res) 
 }
 
 # get the list of codes for a dimension
 getCodes <- function(provider, flow, dimension){
-  javaKeys<-J("it.bankitalia.reri.sia.sdmx.client.SdmxClientHandler")$getCodes(provider, flow, dimension)
+  javaKeys<-J("it.bancaditalia.oss.sdmx.client.SdmxClientHandler")$getCodes(provider, flow, dimension)
   keys = convertHashTable(javaKeys)
   return(keys)
 }
 
 # call help browser
 sdmxHelp<- function(){
-  J("it.bankitalia.reri.sia.sdmx.helper.SDMXHelper")$start()
+  J("it.bancaditalia.oss.sdmx.helper.SDMXHelper")$start()
+}
+
+# convert from list of zoo to data.frame
+sdmxdf<- function(tslist, meta=F){
+  ddf = NULL
+  if(!missing(tslist) && length(tslist) != 0 && is.list(tslist)){
+    dflist=lapply(tslist, sdmxzoo2df, meta)
+    ddf=Reduce(function(x, y) merge(x, y, all=TRUE), dflist)
+    rownames(ddf)<-NULL
+  }
+  else{
+    cat('The time series list in input is missing or invalid\n')
+  }
+  return(ddf)
 }
\ No newline at end of file
