@@ -21,6 +21,39 @@
 
 # Basic class for converting from Java objects to R
 
+# convert a zoo to a df
+sdmxzoo2df <- function (tts, meta) {
+  ddf = NULL
+  if(!missing(tts) && length(tts) != 0 && is.zoo(tts)){
+    n = length(tts)
+    time=as.character(index(tts))
+    data=as.numeric(tts)
+    id=rep(attr(tts, 'ID'), n)
+    status=attr(tts, 'STATUS')
+    header=c('ID', 'TIME', 'OBS')
+    if(length(status) == n){
+      ddf=data.frame(id, time, data, status)
+      header=append(header, 'STATUS')
+    }
+    else{
+      ddf=data.frame(id, time, data)
+    }
+    if(meta){
+      for(x in names(attributes(tts))){
+        if(x != 'ID' && x != 'class' && x != 'frequency' && x != 'index' && x != 'STATUS'){
+          ddf = cbind(ddf, rep(attr(tts, x), n))
+          header=append(header, x)
+        }
+      }
+    }
+    colnames(ddf) = header
+  }
+  else{
+    message('The time series in input is missing or invalid\n')
+  }
+  return(ddf)
+}
+
 # convert a java List<String>
 convertStringList <- function (javaList) {
 	rList = as.list(javaList)
@@ -37,7 +70,7 @@ convertDimList <- function (javaList) {
   if( numOfDims > 0 ) {
     for (i in 1:numOfDims)  {
       name=.jcall(rList[[i]],"Ljava/lang/String;","getId");
-      codelist=.jcall(rList[[i]],"Lit/bankitalia/reri/sia/sdmx/api/Codelist;","getCodeList");
+      codelist=.jcall(rList[[i]],"Lit/bancaditalia/oss/sdmx/api/Codelist;","getCodeList");
       codelist = .jcall(codelist,"Ljava/lang/String;","getFullIdentifier");
       result[[name]] = codelist
     }
@@ -66,7 +99,7 @@ convertTSList <- function (javaList) {
 
 	rList = as.list(javaList);
 	numOfTS = length(rList);
-	#print(paste("Found ", numOfTS, " timeseries"));
+	#message(paste("Found ", numOfTS, " timeseries\n"));
 	#result = list();
 	names = lapply(X=rList, FUN=getNames)
 	result = lapply(X=rList, FUN=convertSingleTS)
@@ -76,35 +109,36 @@ convertTSList <- function (javaList) {
 }
 
 getNames<-function(ttss){
-  s = .jcast(ttss, new.class = "it/bankitalia/reri/sia/sdmx/api/PortableTimeSeries", check = TRUE);
+  s = .jcast(ttss, new.class = "it/bancaditalia/oss/sdmx/api/PortableTimeSeries", check = TRUE);
   name = .jcall(s,"Ljava/lang/String;","getName", evalString = TRUE);
   return(name)
 }
 
 convertSingleTS<-function(ttss){
-    s = .jcast(ttss, new.class = "it/bankitalia/reri/sia/sdmx/api/PortableTimeSeries", check = TRUE);
-    name = .jcall(s,"Ljava/lang/String;","getName", evalString = TRUE);
-    freq = .jcall(s,"Ljava/lang/String;","getFrequency", evalString = TRUE);
-    dimensions = .jcall(s,"[Ljava/lang/String;","getDimensionsArray", evalArray = TRUE,
-                        evalString = TRUE);
-    attributes = .jcall(s,"[Ljava/lang/String;","getAttributesArray", evalArray = TRUE,
-                        evalString = TRUE);
-    timeSlots = .jcall(s,"[Ljava/lang/String;","getTimeSlotsArray", evalArray = TRUE,
-                       evalString = TRUE);
-    observationsJ = .jcall(s,"[Ljava/lang/Double;","getObservationsArray", evalArray = TRUE);
-    status = .jcall(s,"[Ljava/lang/String;","getStatusArray", evalArray = TRUE,
-                    evalString = TRUE);
-    numOfObs = length(observationsJ);
-    numOfTimes = length(timeSlots);
-    if( numOfObs > 0 && numOfObs == numOfTimes){
-      observations = sapply(observationsJ, .jcall,"D","doubleValue")
+  tts = NULL  
+  s = .jcast(ttss, new.class = "it/bancaditalia/oss/sdmx/api/PortableTimeSeries", check = TRUE);
+  name = .jcall(s,"Ljava/lang/String;","getName", evalString = TRUE);
+  freq = .jcall(s,"Ljava/lang/String;","getFrequency", evalString = TRUE);
+  dimensions = .jcall(s,"[Ljava/lang/String;","getDimensionsArray", evalArray = TRUE,
+                      evalString = TRUE);
+  attributes = .jcall(s,"[Ljava/lang/String;","getAttributesArray", evalArray = TRUE,
+                      evalString = TRUE);
+  timeSlots = .jcall(s,"[Ljava/lang/String;","getTimeSlotsArray", evalArray = TRUE,
+                     evalString = TRUE);
+  observationsJ = .jcall(s,"[Ljava/lang/Double;","getObservationsArray", evalArray = TRUE);
+  status = .jcall(s,"[Ljava/lang/String;","getStatusArray", evalArray = TRUE,
+                  evalString = TRUE);
+  numOfObs = length(observationsJ);
+  numOfTimes = length(timeSlots);
+  if( numOfObs > 0 && numOfObs == numOfTimes){
+    observations = sapply(observationsJ, .jcall,"D","doubleValue")
 
-      tts = makeSDMXTS(name, freq, timeSlots, observations, attributes, dimensions, status);
-    }
-    else{
-      print(paste("Number of observations and time slots equal to zero, or not matching: ", numOfObs, " ", numOfTimes));
-    }
-    return(tts)
+    tts = makeSDMXTS(name, freq, timeSlots, observations, attributes, dimensions, status);
+  }
+  else{
+    message(paste("Error building timeseries '", name, "': number of observations and time slots equal to zero, or not matching: ", numOfObs, " ", numOfTimes, "\n"));
+  }
+  return(tts)
 }
 
 # parameters used:
@@ -121,7 +155,7 @@ makeSDMXTS<- function (tsname,freq,times,values,series_attr, series_dims, status
 	if(length(values > 0)) {
 
 		if (is.null(freq)) {
-			print ("Frequency is NULL. Irregular timeseries defined")
+			message ("Frequency is NULL. Irregular timeseries defined\n")
 			tmp_ts <- zoo(values, order.by=times)
 		}
 		else {
@@ -133,7 +167,7 @@ makeSDMXTS<- function (tsname,freq,times,values,series_attr, series_dims, status
       } else if(freq == 'Q'){
         tmp_ts<- zoo(values, order.by = as.yearqtr(sub(pattern='-', replacement=' ', times)),frequency=4)
       } else if(freq == 'D' || freq == 'B'){
-        tmp_ts<- zoo(values, order.by = as.Date(times),frequency=4)
+        tmp_ts<- zoo(values, order.by = as.Date(times))
       } else {
 	      tmp_ts <- zoo(values, order.by=times)
       }
